==> eagle-i-ui-gwt-1.0-MS6.09-sources.jar: org/eaglei/ui/gwt/home/HomePage.java <==
package org.eaglei.ui.gwt.home;

import org.eaglei.search.provider.SearchRequest;
import org.eaglei.ui.gwt.ApplicationContext;
import org.eaglei.ui.gwt.search.SearchBar;
import org.eaglei.ui.gwt.search.SearchContext;
import org.eaglei.ui.gwt.search.SearchBar.SearchRequestListener;
import org.eaglei.ui.gwt.security.SessionContext;

import com.google.gwt.core.client.GWT;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.Widget;

public class HomePage extends Composite {

	interface MyUiBinder extends UiBinder<Widget, HomePage> {
	}

	private static MyUiBinder uiBinder = GWT.create(MyUiBinder.class);

	@UiField
	SearchBar searchBar;

	public HomePage() {
		initWidget(uiBinder.createAndBindUi(this));
		searchBar.addSearchRequestListener(new SearchRequestListener() {

			@Override
			public void onRequest(SearchRequest request) {
	            if (SessionContext.getSessionId() == null) {
	                Window.alert("Please login");
	                return;
	            }
                SearchContext.INSTANCE.search(request);
			}

		});
		searchBar.sizeToParent(960);
	}

	public void setPageParams(String params) {
        SearchRequest request = new SearchRequest(params);
        SearchContext.INSTANCE.setCurrentRequest(request);
        if (params == null || params.length() == 0) {
            SearchContext.INSTANCE.clearSearch();
        } else {
            // Support search request params
        }

	}

}

==> eagle-i-ui-gwt-1.1-MS1.01-sources.jar: org/eaglei/ui/gwt/home/HomePage.java <==
package org.eaglei.ui.gwt.home;

import org.eaglei.search.provider.SearchRequest;
import org.eaglei.ui.gwt.ApplicationContext;
import org.eaglei.ui.gwt.search.SearchBar;
import org.eaglei.ui.gwt.search.SearchContext;
import org.eaglei.ui.gwt.search.SearchBar.SearchRequestListener;
import org.eaglei.ui.gwt.security.SessionContext;

import com.google.gwt.core.client.GWT;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.Widget;

public class HomePage extends Composite {

	interface MyUiBinder extends UiBinder<Widget, HomePage> {
	}

	private static MyUiBinder uiBinder = GWT.create(MyUiBinder.class);

	@UiField
	SearchBar searchBar;

	public HomePage() {
		initWidget(uiBinder.createAndBindUi(this));
		searchBar.addSearchRequestListener(new SearchRequestListener() {

			@Override
			public void onRequest(SearchRequest request) {
	            if (SessionContext.getSessionId() == null) {
	                Window.alert("Please login");
	                return;
	            }
                SearchContext.INSTANCE.search(request);
			}

		});
		searchBar.sizeToParent(960);
	}

	public void setPageParams(String params) {
	    // The problem with setting the SearchContext on the Home page
	    // is that it will automatically kick off a Search All operation
	    //SearchContext.INSTANCE.setFromHistoryParams(params);
	}

}
